@@ -21,7 +21,7 @@
  */
 
 /*
- *$Id: cr-term.c,v 1.2 2003/06/20 22:08:50 dodji Exp $
+ *$Id: cr-term.c,v 1.3 2003/12/11 10:31:37 dodji Exp $
  */
 #include <stdio.h>
 #include <string.h>
@@ -321,7 +321,7 @@ cr_term_to_string (CRTerm *a_this)
                     && (cur->content.rgb == NULL))
                         continue ;
                 
-                switch (cur->operator)
+                switch (cur->the_operator)
                 {
                 case DIVIDE:
                         g_string_append_printf (str_buf, " / ") ;
